# FAIRsoft 

Library for the aggregation of Life Sciences software metadata and FAIR evaluation.


## Installation 
Install using [pip](https://pip.pypa.io/en/stable/):
```
pip install FAIRsoft
``` 

### Requirements 
In order to use the Bioconda and repositories (GitHub and Bitbucket) importers, the following two tools need to be installed:

- [opeb-enrichers/repoEnricher](https://github.com/inab/opeb-enrichers).

- [bioconda-utils](https://github.com/bioconda/bioconda-utils): bioconda package, requires [Conda](https://docs.conda.io/projects/conda/en/latest/index.html). 


## Usage 
Example of usage in this [jupyter-notebook](https://gitlab.bsc.es/inb/elixir/software-observatory/FAIRsoft_ETL/-/blob/master/docs/ETL_workflow.ipynb).
